@@ -2,13 +2,14 @@
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (ADMIN_LEVEL);
 
-$smarty = new Smarty_Bibledit (__FILE__);
+Assets_Page::header (gettext ("Collaboration"));
+$view = new Assets_View (__FILE__);
 
 $which_git = new Filter_Which ("git");
-$smarty->assign ("git", $which_git->available);
+$view->view->git = $which_git->available;
 
 $object = $_GET ['object'];
-$smarty->assign ("object", $object);
+$view->view->object = $object;
 
 $database_config_user = Database_Config_User::getInstance();
 if (isset($_POST['url'])) {
@@ -16,12 +17,13 @@ if (isset($_POST['url'])) {
   $database_config_user->setRemoteRepositoryUrl ($object, $url);
 }
 $url = $database_config_user->getRemoteRepositoryUrl ($object);
-$smarty->assign ("url", $url);
+$view->view->url = $url;
 
 ob_start ();
 $username = system ("whoami");
 ob_end_clean();
-$smarty->assign ("username", $username);
+$view->view->username = $username;
 
-$smarty->display("collaboration_flash_drive_setup.tpl");
-?>
\ No newline at end of file
+$view->render ("collaboration_flash_drive_setup.php");
+Assets_Page::footer ();
+?>
