@@ -1,11 +1,13 @@
 <?php
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (ADMIN_LEVEL);
-$smarty = new Smarty_Bibledit (__FILE__);
+Assets_Page::header (gettext ("Collaboration"));
+$view = new Assets_View (__FILE__);
 $object = $_GET ['object'];
-$smarty->assign ("object", $object);
+$view->view->object = $object;
 $database_config_user = Database_Config_User::getInstance();
 $url = $database_config_user->getRemoteRepositoryUrl ($object);
 $directory = Filter_Git::git_directory ($object);
-$smarty->display("collaboration_repo_data.tpl");
-?>
\ No newline at end of file
+$view->render ("collaboration_repo_data.php");
+Assets_Page::footer ();
+?>
