@@ -5,18 +5,19 @@ page_access_level (ADMIN_LEVEL);
 
 Assets_Page::header (gettext ("Collaboration"));
 
-$smarty = new Smarty_Bibledit (__FILE__);
+$view = new Assets_View (__FILE__);
 
 $object = $_GET ['object'];
-$smarty->assign ("object", $object);
+$view->view->object = $object;
 
 $database_config_user = Database_Config_User::getInstance();
 $url = $database_config_user->getRemoteRepositoryUrl ($object);
-$smarty->assign ("url", $url);
+$view->view->url = $url;
 
 $ready = false;
 $database_shell = Database_Shell::getInstance ();
 $output = "";
+$contents = array ();
 switch ($database_shell->logic ("collaboration_take_yourself", 0, $output)) {
   case 1: 
     $workingdirectory = dirname (__FILE__);
@@ -31,12 +32,12 @@ switch ($database_shell->logic ("collaboration_take_yourself", 0, $output)) {
     $ready = true;
     break;
 }
-@$smarty->assign ("contents", $contents);
+$view->view->contents = $contents;
 
 // Display the page(s).
-$smarty->display("collaboration_take_yourself1.tpl");
-if ($ready) $smarty->display("collaboration_take_yourself2.tpl");
+$view->render ("collaboration_take_yourself1.php");
+if ($ready) $view->render ("collaboration_take_yourself2.php");
 
 Assets_Page::footer ();
 
-?>
\ No newline at end of file
+?>
