@@ -10,4 +10,11 @@ $site_admin_username = "adminusername";
 // Password.
 $site_admin_password = "adminpassword";
 
+// Whether this is an open installation.
+// false: It is the standard password protected installation.
+// true: It is an open installation.
+
+// Open installation.
+$open_installation = false;
+
 ?>
