@@ -23,38 +23,44 @@
 
 class Assets_Page 
 {
+
   public static function header ($title, $query = "")
   {
-    $smarty = new Smarty_Bibledit (__FILE__);
-    $smarty->assign ("title", $title);
-    $smarty->assign ("query", $query);
-    $smarty->display ("xhtml_start.tpl");
-    $smarty->display ("header_full.tpl");
+    $view = new Assets_View (__FILE__);
+    $view->view->title = $title;
+    $view->view->query = $query;
+    $view->render ("xhtml_start.php");
+    $view->render ("header_full.php");
   }
+
   public static function success ($message)
   {
-    $smarty = new Smarty_Bibledit (__FILE__);
-    $smarty->assign ("message", $message);
-    $smarty->display ("success.tpl");
+    $view = new Assets_View (__FILE__);
+    $view->view->message = $message;
+    $view->render ("success.php");
   }
+
   public static function error ($message)
   {
-    $smarty = new Smarty_Bibledit (__FILE__);
-    $smarty->assign ("message", $message);
-    $smarty->display ("error.tpl");
+    $view = new Assets_View (__FILE__);
+    $view->view->message = $message;
+    $view->render ("error.php");
   }
+
   public static function message ($message)
   {
-    $smarty = new Smarty_Bibledit (__FILE__);
-    $smarty->assign ("message", $message);
-    $smarty->display ("message.tpl");
+    $view = new Assets_View (__FILE__);
+    $view->view->message = $message;
+    $view->render ("message.php");
   }
+
   public static function footer ()
   {
-    $smarty = new Smarty_Bibledit (__FILE__);
-    $smarty->display ("footer_full.tpl");
-    $smarty->display ("xhtml_finish.tpl");
+    $view = new Assets_View (__FILE__);
+    $view->render ('footer_full.php');
+    $view->render ('xhtml_finish.php');
   }
+
 }
 
 
