@@ -133,7 +133,9 @@ class Database_Bibles
     $query = "SELECT versification FROM bible_names WHERE name = '$name';";
     $result = $database_instance->runQuery ($query);
     $row = $result->fetch_row();
-    return $row[0];
+    $versification = $row[0];
+    if ($versification == "") $versification = "English";
+    return $versification;
   }
 
 
@@ -421,6 +423,21 @@ class Database_Bibles
   }
       
 
+  /*
+   * Deletes the diffs for one chapter of a Bible.
+   */
+  public function deleteDiffChapter ($bible, $book, $chapter)
+  {
+    $database_instance = Database_Instance::getInstance();
+    $bible = Database_SQLInjection::no ($bible);
+    if (!is_numeric ($bible)) $bible = $this->getID ($bible);
+    $book = Database_SQLInjection::no ($book);
+    $chapter = Database_SQLInjection::no ($chapter);
+    $query = "DELETE FROM bible_diff WHERE bible = $bible AND book = $book AND chapter = $chapter;";
+    $result = $database_instance->runQuery ($query);
+  }
+      
+
   /*
    * Returns an array with the available chapters that have diff data in a $book in a Bible.
    */
