@@ -168,20 +168,6 @@ class Database_Config_General
     $this->setValue ("timer-minute", $value);
   }
 
-  public function getPublicSshKey() {
-    return $this->getValue ("public-ssh-key", "");
-  }
-  public function setPublicSshKey ($value) {
-    $this->setValue ("public-ssh-key", $value);
-  }
-
-  public function getPrivateSshKey() {
-    return $this->getValue ("private-ssh-key", "");
-  }
-  public function setPrivateSshKey ($value) {
-    $this->setValue ("private-ssh-key", $value);
-  }
-
   public function getTimezone() {
     return $this->getValue ("timezone", "UTC");
   }
@@ -364,6 +350,13 @@ class Database_Config_General
     $this->setValue ("sentence-structure", $value);
   }
 
+  public function getCheckParagraphStructure () {
+    return $this->getValue ("paragraph-structure", "");
+  }
+  public function setCheckParagraphStructure ($value) {
+    $this->setValue ("paragraph-structure", $value);
+  }
+
   public function getSentenceStructureCapitals () {
     return $this->getValue ("sentence-structure-capitals", "A B C D E F G H I J K L M N O P Q R S T U V W X Y Z");
   }
@@ -406,6 +399,48 @@ class Database_Config_General
     $this->setList ("sentence-structure-names", $value);
   }
 
+  public function getCheckChaptesVersesVersification () {
+    return $this->getValue ("check-chapters-verses-versification", "");
+  }
+  public function setCheckChaptesVersesVersification ($value) {
+    $this->setValue ("check-chapters-verses-versification", $value);
+  }
+
+  public function getSwordConfiguration () {
+    return $this->getList ("sword-configuration", "");
+  }
+  public function setSwordConfiguration ($value) {
+    $this->setList ("sword-configuration", $value);
+  }
+
+  public function getCheckWellFormedUsfm () {
+    return $this->getValue ("check-well-formed-usfm", "");
+  }
+  public function setCheckWellFormedUsfm ($value) {
+    $this->setValue ("check-well-formed-usfm", $value);
+  }
+
+  public function getCheckMissingPunctuationEndVerse () {
+    return $this->getValue ("missing-punctuation-end-verse", "");
+  }
+  public function setCheckMissingPunctuationEndVerse ($value) {
+    $this->setValue ("missing-punctuation-end-verse", $value);
+  }
+
+  public function getCheckPatterns () {
+    return $this->getValue ("check_patterns", "");
+  }
+  public function setCheckPatterns ($value) {
+    $this->setValue ("check_patterns", $value);
+  }
+
+  public function getCheckingPatterns () {
+    return $this->getList ("checking-patterns", "");
+  }
+  public function setCheckingPatterns ($value) {
+    $this->setList ("checking-patterns", $value);
+  }
+
 }
 
 
