@@ -49,8 +49,36 @@ class Database_Config_User
     $query = "INSERT INTO config_user VALUES (NULL, '$username', '$bible', '$key', '$value', 0);";    
     $database->runQuery ($query);
   }
-
-
+  public function getList ($bible, $key) {
+    $session_logic = Session_Logic::getInstance();
+    $username = $session_logic->currentUser();
+    $username = Database_SQLInjection::no ($username);
+    $bible = Database_SQLInjection::no ($bible);
+    $database = Database_Instance::getInstance ();
+    $query = "SELECT value FROM config_user WHERE username = '$username' AND bible = '$bible' AND ident = '$key' ORDER BY offset;";
+    $result = $database->runQuery ($query);
+    $list = array ();
+    for ($i = 0; $i < $result->num_rows; $i++) {
+      $result_array = $result->fetch_row();
+      $list [] = $result_array [0];
+    }
+    return $list;
+  }
+  public function setList ($bible, $key, $values) {
+    $session_logic = Session_Logic::getInstance();
+    $username = $session_logic->currentUser();
+    $username = Database_SQLInjection::no ($username);
+    $bible = Database_SQLInjection::no ($bible);
+    $database = Database_Instance::getInstance ();
+    $query = "DELETE FROM config_user WHERE username = '$username' AND bible = '$bible' AND ident = '$key';";
+    $database->runQuery ($query);
+    foreach ($values as $offset => $value) {
+      $offset = Database_SQLInjection::no ($offset);
+      $value = Database_SQLInjection::no ($value);
+      $query = "INSERT INTO config_user VALUES (NULL, '$username', '$bible', '$key', '$value', $offset);";    
+      $database->runQuery ($query);
+    }
+  }
   private function getValueForBible ($bible, $key, $default) {
     $bible = Database_SQLInjection::no ($bible);
     $database = Database_Instance::getInstance ();
@@ -175,6 +203,16 @@ class Database_Config_User
     $this->setValue ("", "get-assigned-to-consultation-notes-changes", $value);
   }   
 
+  public function getGenerateChangeNotifications() {
+    return $this->getValue ("", "generate-change-notifications", false);
+  }
+  public function getUserGenerateChangeNotifications($username) {
+    return $this->getValueForUser ($username, "generate-change-notifications", false);
+  }
+  public function setGenerateChangeNotifications ($value) {
+    $this->setValue ("", "generate-change-notifications", $value);
+  }   
+
   public function getAssignedConsultationNoteNotification() {
     return $this->getValue ("", "assigned-consultation-note-notification", true);
   }
@@ -295,7 +333,7 @@ class Database_Config_User
   public function setDeletedConsultationNoteNotification ($value) {
     $this->setValue ("", "deleted-consultation-note-notification", $value);
   }   
-     
+
   public function getBibleChecksNotification () {
     return $this->getValue ("", "bible-checks-notification", false);
   }
@@ -306,6 +344,63 @@ class Database_Config_User
     $this->setValue ("", "bible-checks-notification", $value);
   }   
 
+  public function getPendingChangesNotification () {
+    return $this->getValue ("", "pending-changes-notification", false);
+  }
+  public function getUserPendingChangesNotification ($username) {
+    return $this->getValueForUser ($username, "pending-changes-notification", false);
+  }
+  public function setPendingChangesNotification ($value) {
+    $this->setValue ("", "pending-changes-notification", $value);
+  }   
+
+  public function getAssignedNotesStatisticsNotification () {
+    return $this->getValue ("", "assigned-notes-statistics-notification", false);
+  }
+  public function getUserAssignedNotesStatisticsNotification ($username) {
+    return $this->getValueForUser ($username, "assigned-notes-statistics-notification", false);
+  }
+  public function setAssignedNotesStatisticsNotification ($value) {
+    $this->setValue ("", "assigned-notes-statistics-notification", $value);
+  }   
+
+  public function getSubscribedNotesStatisticsNotification () {
+    return $this->getValue ("", "subscribed-notes-statistics-notification", false);
+  }
+  public function getUserSubscribedNotesStatisticsNotification ($username) {
+    return $this->getValueForUser ($username, "subscribed-notes-statistics-notification", false);
+  }
+  public function setSubscribedNotesStatisticsNotification ($value) {
+    $this->setValue ("", "subscribed-notes-statistics-notification", $value);
+  }   
+
+  public function getNotifyMeOfMyPosts () {
+    return $this->getValue ("", "notify-me-of-my-posts", true);
+  }
+  public function getUserNotifyMeOfMyPosts ($username) {
+    return $this->getValueForUser ($username, "notify-me-of-my-posts", true);
+  }
+  public function setNotifyMeOfMyPosts ($value) {
+    $this->setValue ("", "notify-me-of-my-posts", $value);
+  }   
+
+  public function getSuppressMailFromYourUpdatesNotes () {
+    return $this->getValue ("", "suppress-mail-my-updated-notes", false);
+  }
+  public function getUserSuppressMailFromYourUpdatesNotes ($username) {
+    return $this->getValueForUser ($username, "suppress-mail-my-updated-notes", false);
+  }
+  public function setSuppressMailFromYourUpdatesNotes ($value) {
+    $this->setValue ("", "suppress-mail-my-updated-notes", $value);
+  }   
+
+  public function getActiveResources () {
+    return $this->getList ("", "active-resources");
+  }
+  public function setActiveResources ($values) {
+    $this->setList ("", "active-resources", $values);
+  }   
+
 }
 
 
