@@ -75,9 +75,16 @@ class Database_Git
     $server = Database_Instance::getInstance ();
     $result = $server->runQuery ("DELETE FROM git WHERE directory = '$directory' AND output = '$output';");
   }
+  
+  
+  public function truncate ()
+  {
+    $server = Database_Instance::getInstance ();
+    $result = $server->runQuery ("DELETE FROM git;");
+  }
 
 
 }
 
 
-?>
\ No newline at end of file
+?>
