@@ -3,7 +3,7 @@
 
 class Dialog_Books2
 {
-  private $smarty;
+  private $view;
     
   /**
   * Constructs a book dialog
@@ -13,14 +13,14 @@ class Dialog_Books2
   */
   public function __construct ($header, $info_top, $info_bottom, $action, $inclusions, $exclusions)
   {
-    $this->smarty = new Smarty_Bibledit (__FILE__);
+    $this->view = new Assets_View (__FILE__);
     $database_sessions = Database_Sessions::getInstance();
     $caller = $_SERVER["PHP_SELF"] . "?" . http_build_query (array ("session" => $database_sessions->getCurrentSessionId ()));
-    $this->smarty->assign ("caller", $caller);
-    $this->smarty->assign ("header", $header);
-    $this->smarty->assign ("info_top", $info_top);
-    $this->smarty->assign ("info_bottom", $info_bottom);
-    $this->smarty->assign ("action", $action);
+    $this->view->view->caller = $caller;
+    $this->view->view->header = $header;
+    $this->view->view->info_top = $info_top;
+    $this->view->view->info_bottom = $info_bottom;
+    $this->view->view->action = $action;
 
     $database_books = Database_Books::getInstance();
     $book_ids = $database_books->getIDs ();
@@ -34,9 +34,9 @@ class Dialog_Books2
     foreach ($book_ids as $id) {
       $book_names[] = $database_books->getEnglishFromId ($id);
     }
-    $this->smarty->assign ("book_ids", $book_ids);
-    $this->smarty->assign ("book_names", $book_names);
-    $this->smarty->display("books2.tpl");
+    $this->view->view->book_ids = $book_ids;
+    $this->view->view->book_names = $book_names;
+    $this->view->render ("books2.php");
     Assets_Page::footer();
     die;
   }
