@@ -3,11 +3,11 @@
 
 class Dialog_Color
 {
-  private $smarty;
+  private $view;
 
   public function __construct ($query, $question, $item) 
   {
-    $this->smarty = new Smarty_Bibledit (__FILE__);
+    $this->view = new Assets_View (__FILE__);
     $base_url = $_SERVER['PHP_SELF'];
     if (is_array ($query)) {
       $base_url .= "?" . http_build_query ($query);
@@ -16,10 +16,11 @@ class Dialog_Color
       $active_url = $base_url . "?";
     }
     $active_url .= $item . "=";
-    $this->smarty->assign ("base_url",   $base_url);
-    $this->smarty->assign ("active_url", $active_url);
-    $this->smarty->assign ("question",   $question);
-    $this->smarty->display("color.tpl");
+    $this->view->view->base_url = $base_url;
+    $this->view->view->active_url = $active_url;
+    $this->view->view->question = $question;
+    $this->view->render ("color.php");
+    Assets_Page::footer ();
   }
 }
 
