@@ -3,7 +3,7 @@
 
 class Dialog_Yes2
 {
-  private $smarty;
+  private $view;
 
   /**
   * Dialog that asks the user for confirmation to perform an action.
@@ -13,17 +13,17 @@ class Dialog_Yes2
   */
   public function __construct ($question, $action)
   {
-    $this->smarty = new Smarty_Bibledit (__FILE__);
+    $this->view = new Assets_View (__FILE__);
     $database_sessions = Database_Sessions::getInstance ();
     $caller_url = $_SERVER["PHP_SELF"] . "?" . http_build_query (array ("session" => $database_sessions->getCurrentSessionId ()));
-    $this->smarty->assign ("caller_url", $caller_url);
-    $this->smarty->assign ("action", $action);
-    $this->smarty->assign ("question",     $question);
-    $this->smarty->display("yes2.tpl");
+    $this->view->view->caller_url = $caller_url;
+    $this->view->view->action = $action;
+    $this->view->view->question = $question;
+    $this->view->render ("yes2.php");
     Assets_Page::footer ();
     die ();
   }
 }
 
 
-?>
\ No newline at end of file
+?>
