@@ -5,7 +5,7 @@ class Filter_Backup
 {
 
 
-  public function file ()
+  public static function file ()
   {
     $config_general = Database_Config_General::getInstance ();
     $value = $config_general->getBackupFile ();
@@ -21,4 +21,4 @@ class Filter_Backup
 }
 
 
-?>
+?>
\ No newline at end of file
