@@ -3,7 +3,7 @@
 * @package bibledit
 */
 /*
- ** Copyright (©) 2003-2012 Teus Benschop.
+ ** Copyright (©) 2003-2013 Teus Benschop.
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -55,16 +55,6 @@ class Filter_Character
   }
 
 
-  /**
-  * Returns an "em space", this is a mutton, nominally a space equal to the height of the font.
-  */
-  public static function emSpace ()
-  {
-    // The space below is U+2003.
-    return " ";
-  }
-
-
 }
 
-?>
\ No newline at end of file
+?>
