@@ -83,6 +83,7 @@ class Filter_Text
   private $heading_started; // Flag for headings per verse processor.
   private $verses_text; // Array to hold verse numbers and the plain text in that verse, without anything extra.
   private $text_started; // Flag for text per verse processor.
+  public $paragraph_start_positions; // Positions, in graphemes, where paragraphs start in verses_text.
 
   
   /**
@@ -261,8 +262,6 @@ class Filter_Text
                       $s = str_replace (Filter_Character::softHyphen (), "", $s); // Remove possible soft hyphen.
                       $database_books = Database_Books::getInstance ();
                       $this->currentBookIdentifier = $database_books->getIdFromUsfm ($s);
-                      // Output to some export formats.
-                      if ($this->esword_text) $this->esword_text->newBook ($this->currentBookIdentifier);
                       // Reset chapter and verse numbers.
                       $this->currentChapterNumber = 0;
                       $this->numberOfChaptersPerBook[$this->currentBookIdentifier] = 0;
@@ -431,6 +430,8 @@ class Filter_Text
                     $this->resetNoteCitations ('book');
                     // Online Bible.
                     if ($this->onlinebible_text) $this->onlinebible_text->storeData ();
+                    // eSword.
+                    if ($this->esword_text) $this->esword_text->newBook ($this->currentBookIdentifier);
                     // Done.
                     break;
                   }
@@ -532,13 +533,18 @@ class Filter_Text
                   default:
                   {
                     $this->newParagraph ($style, false);
+                    $this->heading_started = false;
                     $this->text_started = true;
-                    // If a new paragraph starts within an existing verse, 
-                    // add a space to the text already in that verse.
                     if (is_array ($this->verses_text)) {
+                      // If a new paragraph starts within an existing verse, 
+                      // add a space to the text already in that verse.
                       if (isset ($this->verses_text [$this->currentVerseNumber])) {
                         $this->verses_text [$this->currentVerseNumber] .= " ";
                       }
+                      // Record the position within the text where this new paragraph starts.
+                      $contents = implode ('', $this->verses_text);
+                      $this->paragraph_start_positions [] = grapheme_strlen ($contents);
+                      unset ($contents);
                     }
                     break;
                   }
@@ -976,8 +982,10 @@ class Filter_Text
             $this->text_text->text ($currentItem);
           }
           if (is_array ($this->verses_headings) && $this->heading_started) {
-            $this->verses_headings [$this->currentVerseNumber] = $currentItem;
-            $this->heading_started = false;
+            if (!isset ($this->verses_headings [$this->currentVerseNumber])) {
+              $this->verses_headings [$this->currentVerseNumber] = "";
+            }
+            $this->verses_headings [$this->currentVerseNumber] .= $currentItem;
           }
           if (is_array ($this->verses_text) && $this->text_started) {
             if (isset ($this->verses_text [$this->currentVerseNumber])) {
@@ -1625,6 +1633,7 @@ class Filter_Text
   {
     $this->verses_headings = array ();
     $this->verses_text = array ();
+    $this->paragraph_start_positions = array ();
   }  
 
 
