@@ -2,9 +2,9 @@
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (GUEST_LEVEL);
 Assets_Page::header (gettext ("About"));
-$smarty = new Smarty_Bibledit (__FILE__);
+$view = new Assets_View (__FILE__);
 include ("version.php");
-$smarty->assign ("version", $version);
-$smarty->display("about.tpl");
+$view->view->version = $version;
+$view->render ("about.php");
 Assets_Page::footer ();
-?>
\ No newline at end of file
+?>
