@@ -2,7 +2,7 @@
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (GUEST_LEVEL);
 Assets_Page::header (gettext ("Help"));
-$smarty = new Smarty_Bibledit (__FILE__);
-$smarty->display("index.tpl");
+$view = new Assets_View (__FILE__);
+$view->render ("index.php");
 Assets_Page::footer ();
 ?>
