@@ -2,7 +2,7 @@
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (GUEST_LEVEL);
 Assets_Page::header (gettext ("Introduction"));
-$smarty = new Smarty_Bibledit (__FILE__);
-$smarty->display("introduction.tpl");
+$view = new Assets_View (__FILE__);
+$view->render ('introduction.php');
 Assets_Page::footer ();
 ?>
