@@ -4,7 +4,7 @@
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (MANAGER_LEVEL);
 Assets_Page::header (gettext ("Edit Note Source"));
-$smarty = new Smarty_Bibledit (__FILE__);
+$view = new Assets_View (__FILE__);
 
 
 @$noteIdentifier = $_GET['identifier'];
@@ -21,9 +21,9 @@ if (isset($_POST['data'])) {
   $noteData = $_POST['data'];
   if ($database_notes->identifierExists ($noteIdentifier)) {
     $noteData = $database_notes->setContents ($noteIdentifier, $noteData);
-    $smarty->assign ("success", gettext ("The note was saved"));
+    $view->view->success = gettext ("The note was saved");
   } else {
-    $smarty->assign ("error", gettext ("Unknown Note Identifier"));
+    $view->view->error = gettext ("Unknown Note Identifier");
   }
 }
 
@@ -31,15 +31,15 @@ if (isset($_POST['data'])) {
 if ($noteIdentifier != "") {
   if ($database_notes->identifierExists ($noteIdentifier)) {
     $noteData = $database_notes->getContents ($noteIdentifier);
-    $smarty->assign ("data", $noteData);
+    $view->view->data = $noteData;
   } else {
-    $smarty->assign ("error", gettext ("Unknown Note Identifier"));
+    $view->view->error = gettext ("Unknown Note Identifier");
   }
 }
 
 
-$smarty->assign ("identifier", $noteIdentifier);
-$smarty->display("editsource.tpl");
+$view->view->identifier = $noteIdentifier;
+$view->render ("editsource.php");
 
 
 Assets_Page::footer ();
