@@ -6,7 +6,8 @@ page_access_level (GUEST_LEVEL);
 $session_logic = Session_Logic::getInstance ();
 $session_logic->logout ();
 
-$smarty = new Smarty_Bibledit (__FILE__);
-$smarty->display("logout.tpl");
-
-?>
\ No newline at end of file
+Assets_Page::header (gettext ("Logout"));
+$view = new Assets_View (__FILE__);
+$view->render ("logout.php");
+Assets_Page::footer ();
+?>
