@@ -3,7 +3,9 @@
 
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (MANAGER_LEVEL);
-$smarty = new Smarty_Bibledit (__FILE__);
+
+Assets_Page::header (gettext ("Styles"));
+$view = new Assets_View (__FILE__);
 $database_styles = Database_Styles::getInstance();
 
 
@@ -32,8 +34,9 @@ if (isset ($_GET['new'])) {
 
 
 $sheets = $database_styles->getSheets();
-$smarty->assign ("sheets", $sheets);
-$smarty->display ("indexm.tpl");
+$view->view->sheets = $sheets;
+$view->render ("indexm.php");
 
 
-?>
\ No newline at end of file
+Assets_Page::footer ();
+?>
