@@ -3,11 +3,12 @@
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (MANAGER_LEVEL);
 
-$smarty = new Smarty_Bibledit (__FILE__);
+Assets_Page::header (gettext ("Stylesheet"));
+$view = new Assets_View (__FILE__);
 $database_styles = Database_Styles::getInstance();
 
 $name = $_GET['name'];
-$smarty->assign ("name", Filter_Html::sanitize ($name));
+$view->view->name = Filter_Html::sanitize ($name);
 
 if (isset($_POST['submit'])) {
   $data = $_POST['data'];
@@ -28,12 +29,14 @@ foreach ($markers_names as $row) {
   $markers[] =  $row['marker'];
   $names[]=     $row['name'];
 }
-$smarty->assign ("markers", $markers);
-$smarty->assign ("names",   $names);
+$view->view->markers = $markers;
+$view->view->names = $names;
 
 $xml = $database_styles->exportXml ($name);
-$smarty->assign ("xml", $xml);
+$view->view->xml = $xml;
 
-$smarty->display ("sheetm.tpl");
+$view->render ("sheetm.php");
 
-?>
\ No newline at end of file
+Assets_Page::footer ();
+
+?>
