@@ -3,15 +3,17 @@
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (MANAGER_LEVEL);
 
-$smarty = new Smarty_Bibledit (__FILE__);
+Assets_Page::header (gettext ("Style"));
+
+$view = new Assets_View (__FILE__);
 $database_styles = Database_Styles::getInstance();
 $styles_logic = Styles_Logic::getInstance ();
 
 $sheet = $_GET['sheet'];
-$smarty->assign ("sheet", Filter_Html::sanitize ($sheet));
+$view->view->sheet = Filter_Html::sanitize ($sheet);
 
 $style = $_GET['style'];
-$smarty->assign ("style", Filter_Html::sanitize ($style));
+$view->view->style = Filter_Html::sanitize ($style);
 
 $standard_page_query = array ("sheet"=> $sheet, "style" => $style);
 
@@ -27,7 +29,7 @@ if (isset($_POST['name'])) {
   $name = $_POST['entry'];
   $database_styles->updateName ($sheet, $style, $name);
 }
-$smarty->assign ("name", Filter_Html::sanitize ($name));
+$view->view->name = Filter_Html::sanitize ($name);
 
 // The style's info.
 $info = $marker_data['info'];
@@ -39,7 +41,7 @@ if (isset($_POST['info'])) {
   $info = $_POST['entry'];
   $database_styles->updateInfo ($sheet, $style, $info);
 }
-$smarty->assign ("info", Filter_Html::sanitize ($info));
+$view->view->info = Filter_Html::sanitize ($info);
 
 // The style's category.
 $category = $marker_data['category'];
@@ -77,7 +79,7 @@ if (isset ($_GET['category'])) {
     $database_styles->updateCategory ($sheet, $style, $category);
   }
 }
-$smarty->assign ("category", $styles_logic->categoryText($category));
+$view->view->category = $styles_logic->categoryText($category);
 
 // The style's type.
 $type = $marker_data['type'];
@@ -101,8 +103,8 @@ if (isset ($_GET['type'])) {
     $database_styles->updateType ($sheet, $style, $type);
   }
 }
-$smarty->assign ("type", Filter_Html::sanitize ($type));
-$smarty->assign ("type_text", $styles_logic->typeText($type));
+$view->view->type = Filter_Html::sanitize ($type);
+$view->view->type_text = $styles_logic->typeText($type);
 
 // The style's subtype.
 $subtype = $marker_data['subtype'];
@@ -126,11 +128,11 @@ if (isset ($_GET['subtype'])) {
     $database_styles->updateSubType ($sheet, $style, $subtype);
   }
 }
-$smarty->assign ("subtype", Filter_Html::sanitize ($subtype));
-$smarty->assign ("subtype_text", $styles_logic->subtypeText($type, $subtype));
+$view->view->subtype = Filter_Html::sanitize ($subtype);
+$view->view->subtype_text = $styles_logic->subtypeText($type, $subtype);
 
 // The fontsize.
-$smarty->assign ("fontsize_relevant", $styles_logic->fontsizeIsRelevant ($type, $subtype));
+$view->view->fontsize_relevant = $styles_logic->fontsizeIsRelevant ($type, $subtype);
 $fontsize = $marker_data['fontsize'];
 if (isset ($_GET['fontsize'])) {
   $dialog_entry = new Dialog_Entry ($standard_page_query, gettext ("Please enter a fontsize between 5 and 60 points"), $fontsize, "fontsize", gettext ("The value to enter is just a number, e.g. 12."));
@@ -144,10 +146,10 @@ if (isset($_POST['fontsize'])) {
     $database_styles->updateFontsize ($sheet, $style, $fontsize);
   }
 }
-$smarty->assign ("fontsize", Filter_Html::sanitize ($fontsize));
+$view->view->fontsize = Filter_Html::sanitize ($fontsize);
 
 // Italics, bold, underline, small caps relevance.
-$smarty->assign ("ibus_relevant", $styles_logic->italicBoldUnderLineSmallcapsAreRelevant ($type, $subtype));
+$view->view->ibus_relevant = $styles_logic->italicBoldUnderLineSmallcapsAreRelevant ($type, $subtype);
 
 // Italic.
 $italic = $marker_data['italic'];
@@ -170,7 +172,7 @@ if (isset ($_GET['italic'])) {
     $database_styles->updateItalic ($sheet, $style, $italic);
   }
 }
-$smarty->assign ("italic", $styles_logic->OffOnInheritToggleText ($italic));
+$view->view->italic =$styles_logic->OffOnInheritToggleText ($italic);
 
 // Bold.
 $bold   = $marker_data['bold'];
@@ -193,7 +195,7 @@ if (isset ($_GET['bold'])) {
     $database_styles->updateBold ($sheet, $style, $bold);
   }
 }
-$smarty->assign ("bold", $styles_logic->OffOnInheritToggleText ($bold));
+$view->view->bold = $styles_logic->OffOnInheritToggleText ($bold);
 
 // Underline.
 $underline = $marker_data['underline'];
@@ -216,7 +218,7 @@ if (isset ($_GET['underline'])) {
     $database_styles->updateUnderline ($sheet, $style, $underline);
   }
 }
-$smarty->assign ("underline", $styles_logic->OffOnInheritToggleText ($underline));
+$view->view->underline = $styles_logic->OffOnInheritToggleText ($underline);
 
 // Small caps.
 $smallcaps = $marker_data['smallcaps'];
@@ -239,20 +241,20 @@ if (isset ($_GET['smallcaps'])) {
     $database_styles->updateSmallcaps ($sheet, $style, $smallcaps);
   }
 }
-$smarty->assign ("smallcaps", $styles_logic->OffOnInheritToggleText ($smallcaps));
+$view->view->smallcaps = $styles_logic->OffOnInheritToggleText ($smallcaps);
 
 // Superscript.
-$smarty->assign ("superscript_relevant",  $styles_logic->superscriptIsRelevant ($type, $subtype));
+$view->view->superscript_relevant = $styles_logic->superscriptIsRelevant ($type, $subtype);
 $superscript = $marker_data['superscript'];
 if (isset ($_GET['superscript'])) {
   $superscript = Filter_Bool::int ($_GET['superscript']);
   $database_styles->updateSuperscript ($sheet, $style, $superscript);
 }
-$smarty->assign ("superscript_value",  $styles_logic->OffOnInheritToggleText ($superscript));
-$smarty->assign ("superscript_toggle", Filter_Bool::not ($superscript));
+$view->view->superscript_value = $styles_logic->OffOnInheritToggleText ($superscript);
+$view->view->superscript_toggle = Filter_Bool::not ($superscript);
 
 // Whether a list of the following paragraph treats are relevant.
-$smarty->assign ("paragraph_treats_relevant", $styles_logic->paragraphTreatsAreRelevant ($type, $subtype));
+$view->view->paragraph_treats_relevant = $styles_logic->paragraphTreatsAreRelevant ($type, $subtype);
 
 // Text alignment.
 $justification = $marker_data['justification'];
@@ -269,7 +271,7 @@ if (isset ($_GET['justification'])) {
   $justification = $_GET['justification'];
   $database_styles->updateJustification ($sheet, $style, $justification);
 }
-$smarty->assign ("justification", $styles_logic->alignmentText ($justification));
+$view->view->justification = $styles_logic->alignmentText ($justification);
 
 // Space before paragraph.
 $spacebefore = $marker_data['spacebefore'];
@@ -285,7 +287,7 @@ if (isset($_POST['spacebefore'])) {
     $database_styles->updateSpaceBefore ($sheet, $style, $spacebefore);
   }
 }
-$smarty->assign ("spacebefore", Filter_Html::sanitize ($spacebefore));
+$view->view->spacebefore = Filter_Html::sanitize ($spacebefore);
 
 // Space after paragraph.
 $spaceafter = $marker_data['spaceafter'];
@@ -301,7 +303,7 @@ if (isset($_POST['spaceafter'])) {
     $database_styles->updateSpaceAfter ($sheet, $style, $spaceafter);
   }
 }
-$smarty->assign ("spaceafter", Filter_Html::sanitize ($spaceafter));
+$view->view->spaceafter = Filter_Html::sanitize ($spaceafter);
 
 // Left margin.
 $leftmargin = $marker_data['leftmargin'];
@@ -317,7 +319,7 @@ if (isset($_POST['leftmargin'])) {
     $database_styles->updateLeftMargin ($sheet, $style, $leftmargin);
   }
 }
-$smarty->assign ("leftmargin", Filter_Html::sanitize ($leftmargin));
+$view->view->leftmargin = Filter_Html::sanitize ($leftmargin);
 
 // Right margin.
 $rightmargin = $marker_data['rightmargin'];
@@ -333,7 +335,7 @@ if (isset($_POST['rightmargin'])) {
     $database_styles->updateRightMargin ($sheet, $style, $rightmargin);
   }
 }
-$smarty->assign ("rightmargin", Filter_Html::sanitize ($rightmargin));
+$view->view->rightmargin = Filter_Html::sanitize ($rightmargin);
 
 // First line indent.
 $firstlineindent = $marker_data['firstlineindent'];
@@ -349,20 +351,20 @@ if (isset($_POST['firstlineindent'])) {
     $database_styles->updateFirstLineIndent ($sheet, $style, $firstlineindent);
   }
 }
-$smarty->assign ("firstlineindent", Filter_Html::sanitize ($firstlineindent));
+$view->view->firstlineindent = Filter_Html::sanitize ($firstlineindent);
 
 // Columns spanning.
-$smarty->assign ("columns_relevant", $styles_logic->columnsAreRelevant ($type, $subtype));
+$view->view->columns_relevant = $styles_logic->columnsAreRelevant ($type, $subtype);
 $spancolumns = $marker_data['spancolumns'];
 if (isset ($_GET['spancolumns'])) {
   $spancolumns = Filter_Bool::int ($_GET['spancolumns']);
   $database_styles->updateSpanColumns ($sheet, $style, $spancolumns);
 }
-$smarty->assign ("spancolumns", $styles_logic->OffOnInheritToggleText ($spancolumns));
-$smarty->assign ("spancolumns_toggle", Filter_Bool::not ($spancolumns));
+$view->view->spancolumns = $styles_logic->OffOnInheritToggleText ($spancolumns);
+$view->view->spancolumns_toggle = Filter_Bool::not ($spancolumns);
 
 // Color.
-$smarty->assign ("color_relevant", $styles_logic->colorIsRelevant ($type, $subtype));
+$view->view->color_relevant = $styles_logic->colorIsRelevant ($type, $subtype);
 $color = $marker_data['color'];
 if (isset ($_GET['color'])) {
   $value = $_GET['color'];
@@ -374,47 +376,47 @@ if (isset ($_GET['color'])) {
     $database_styles->updateColor ($sheet, $style, $color);
   }
 }
-$smarty->assign ("color", Filter_Html::sanitize ($color));
+$view->view->color = Filter_Html::sanitize ($color);
 
 // Whether to print this style.
-$smarty->assign ("print_relevant", $styles_logic->printIsRelevant ($type, $subtype));
+$view->view->print_relevant = $styles_logic->printIsRelevant ($type, $subtype);
 $print = $marker_data['print'];
 if (isset ($_GET['print'])) {
   $print = Filter_Bool::int ($_GET['print']);
   $database_styles->updatePrint ($sheet, $style, $print);
 }
-$smarty->assign ("print", $styles_logic->OffOnInheritToggleText ($print));
-$smarty->assign ("print_toggle", Filter_Bool::not ($print));
+$view->view->print = $styles_logic->OffOnInheritToggleText ($print);
+$view->view->print_toggle = Filter_Bool::not ($print);
 
 // Userbool1
-$smarty->assign ("userbool1_function", $styles_logic->getUserBool1Text ($styles_logic->getUserBool1Function ($type, $subtype)));
+$view->view->userbool1_function = $styles_logic->getUserBool1Text ($styles_logic->getUserBool1Function ($type, $subtype));
 $userbool1 = $marker_data['userbool1'];
 if (isset ($_GET['userbool1'])) {
   $userbool1 = Filter_Bool::int ($_GET['userbool1']);
   $database_styles->updateUserbool1 ($sheet, $style, $userbool1);
 }
-$smarty->assign ("userbool1_value",    $styles_logic->OffOnInheritToggleText ($userbool1));
-$smarty->assign ("userbool1_toggle", Filter_Bool::not ($userbool1));
+$view->view->userbool1_value = $styles_logic->OffOnInheritToggleText ($userbool1);
+$view->view->userbool1_toggle = Filter_Bool::not ($userbool1);
 
 // Userbool2
-$smarty->assign ("userbool2_function", $styles_logic->getUserBool2Text ($styles_logic->getUserBool2Function ($type, $subtype)));
+$view->view->userbool2_function = $styles_logic->getUserBool2Text ($styles_logic->getUserBool2Function ($type, $subtype));
 $userbool2 = $marker_data['userbool2'];
 if (isset ($_GET['userbool2'])) {
   $userbool2 = Filter_Bool::int ($_GET['userbool2']);
   $database_styles->updateUserbool2 ($sheet, $style, $userbool2);
 }
-$smarty->assign ("userbool2_value",    $styles_logic->OffOnInheritToggleText ($userbool2));
-$smarty->assign ("userbool2_toggle", Filter_Bool::not ($userbool2));
+$view->view->userbool2_value = $styles_logic->OffOnInheritToggleText ($userbool2);
+$view->view->userbool2_toggle = Filter_Bool::not ($userbool2);
 
 // Userbool3
-$smarty->assign ("userbool3_function", $styles_logic->getUserBool3Text ($styles_logic->getUserBool3Function ($type, $subtype)));
+$view->view->userbool3_function = $styles_logic->getUserBool3Text ($styles_logic->getUserBool3Function ($type, $subtype));
 $userbool3 = $marker_data['userbool3'];
 if (isset ($_GET['userbool3'])) {
   $userbool3 = Filter_Bool::int ($_GET['userbool3']);
   $database_styles->updateUserbool3 ($sheet, $style, $userbool3);
 }
-$smarty->assign ("userbool3_value",    $styles_logic->OffOnInheritToggleText ($userbool3));
-$smarty->assign ("userbool3_toggle", Filter_Bool::not ($userbool3));
+$view->view->userbool3_value = $styles_logic->OffOnInheritToggleText ($userbool3);
+$view->view->userbool3_toggle = Filter_Bool::not ($userbool3);
 
 // Userint1.
 $userint1 = $marker_data['userint1'];
@@ -422,7 +424,7 @@ switch ($styles_logic->getUserInt1Function ($type, $subtype)) {
   case UserInt1None : 
     break;
   case UserInt1NoteNumbering :
-    $smarty->assign ("userint1_notenumbering", true);
+    $view->view->userint1_notenumbering = true;
     if (isset ($_GET['notenumbering'])) {
       $dialog_list = new Dialog_List (array ("sheet", "style"), gettext ("Would you like to change the numbering of the note?"), "", "");
       $styles_logic = Styles_Logic::getInstance();
@@ -436,10 +438,10 @@ switch ($styles_logic->getUserInt1Function ($type, $subtype)) {
       $userint1 = $_GET['userint1'];
       $database_styles->updateUserint1 ($sheet, $style, $userint1);
     }
-    $smarty->assign ("userint1", $styles_logic->noteNumberingText ($userint1));
+    $view->view->userint1 = $styles_logic->noteNumberingText ($userint1);
     break;
   case UserInt1TableColumnNumber :
-    $smarty->assign ("userint1_columnnumber", true);
+    $view->view->userint1_columnnumber = true;
     if (isset ($_GET['userint1'])) {
       $dialog_entry = new Dialog_Entry ($standard_page_query, gettext ("Please enter a column number between 1 and 4"), $userint1, "userint1", gettext ("This is the column number for the style. The first columm is number 1."));
       die;
@@ -452,7 +454,7 @@ switch ($styles_logic->getUserInt1Function ($type, $subtype)) {
         $database_styles->updateUserint1 ($sheet, $style, $userint1);
       }
     }
-    $smarty->assign ("userint1", $userint1);
+    $view->view->userint1 = $userint1;
     break;
 }
 
@@ -462,7 +464,7 @@ switch ($styles_logic->getUserInt2Function ($type, $subtype)) {
   case UserInt2None :
     break;
   case UserInt2NoteNumberingRestart :
-    $smarty->assign ("userint2_notenumberingrestart", true);
+    $view->view->userint2_notenumberingrestart = true;
     if (isset ($_GET['notenumberingrestart'])) {
       $dialog_list = new Dialog_List (array ("sheet", "style"), gettext ("Would you like to change when the note numbering restarts?"), "", "");
       $styles_logic = Styles_Logic::getInstance();
@@ -476,10 +478,10 @@ switch ($styles_logic->getUserInt2Function ($type, $subtype)) {
       $userint2 = $_GET['userint2'];
       $database_styles->updateUserint2 ($sheet, $style, $userint2);
     }
-    $smarty->assign ("userint2", $styles_logic->noteRestartNumberingText ($userint2));
+    $view->view->userint2 = $styles_logic->noteRestartNumberingText ($userint2);
     break;
   case UserInt2EndnotePosition :
-    $smarty->assign ("userint2_endnoteposition", true);
+    $view->view->userint2_endnoteposition = true;
     if (isset ($_GET['endnoteposition'])) {
       $dialog_list = new Dialog_List (array ("sheet", "style"), gettext ("Would you like to change the position where to dump the endnotes?"), "", "");
       $styles_logic = Styles_Logic::getInstance();
@@ -493,7 +495,7 @@ switch ($styles_logic->getUserInt2Function ($type, $subtype)) {
       $userint2 = $_GET['userint2'];
       $database_styles->updateUserint2 ($sheet, $style, $userint2);
     }
-    $smarty->assign ("userint2", $styles_logic->endNotePositionText ($userint2));
+    $view->view->userint2 = $styles_logic->endNotePositionText ($userint2);
     break;
 }
 
@@ -506,13 +508,13 @@ switch ($styles_logic->getUserString1Function ($type, $subtype)) {
     break;
   case UserString1NoteNumberingSequence :
     if ($userint1 == NoteNumberingUser) {
-      $smarty->assign ("userstring1_numberingsequence", true);
+      $view->view->userstring1_numberingsequence = true;
       $userstring_question = gettext ("Please enter a new note numbering sequence");
       $userstring1_help = gettext ("This gives a sequence for numbering the notes. When for example § † * is entered, the numbering goes like §, †, *, §, †, *, and so forth. Any sequence of characters can be used. Spaces should separate the characters");
     }
     break;
   case UserString1WordListEntryAddition :
-    $smarty->assign ("userstring1_wordlistaddition", true);
+    $view->view->userstring1_wordlistaddition = true;
     $userstring1_question = gettext ("Please enter a new addition to the word list entry");
     $userstring1_help = gettext ("This given an optional string to be added after each definition in the body of text. In some Bibles the unusual words are marked with an asterisk and then explained in a glossary. If you would enter the asterisk here, or indeed any string, Bibledit-Web would include this in the exported documents.");
     break;
@@ -526,7 +528,7 @@ if (isset($_POST['userstring1'])) {
   $database_styles->updateUserstring1 ($sheet, $style, $userstring1);
 }
 if ($userstring1 == "") $userstring1 = "--";
-$smarty->assign ("userstring1", Filter_Html::sanitize ($userstring1));
+$view->view->userstring1 = Filter_Html::sanitize ($userstring1);
 
 // Userstring2
 $userstring2 = $marker_data['userstring2'];
@@ -535,7 +537,7 @@ switch ($styles_logic->getUserString2Function ($type, $subtype)) {
     break;
   case UserString2DumpEndnotesHere :
     if ($userint2 == EndNotePositionAtMarker) {
-      $smarty->assign ("userstring2_dumpendnotes", true);
+      $view->view->userstring2_dumpendnotes = true;
       $userstring2_question = gettext ("Please enter a marker at which the endnotes should be dumped");
       $userstring2_info = gettext ("The marker is to be given without the backslash, e.g. \"zendnotes\".");
     }
@@ -550,10 +552,12 @@ if (isset($_POST['userstring2'])) {
   $database_styles->updateUserstring2 ($sheet, $style, $userstring2);
 }
 if ($userstring2 == "") $userstring2 = "--";
-$smarty->assign ("userstring2", Filter_Html::sanitize ($userstring2));
+$view->view->userstring2 = Filter_Html::sanitize ($userstring2);
 
 // Userstring3 not yet used.
 
-$smarty->display ("view.tpl");
+$view->render ("view.php");
 
-?>
\ No newline at end of file
+Assets_Page::footer ();
+
+?>
