@@ -24,12 +24,12 @@
 
 require_once ("../bootstrap/bootstrap.php");
 $database_logs = Database_Logs::getInstance ();
-$database_logs->log ("exports: Exporting the Bibles", true);
+$database_logs->log ("exports: Exporting the Bibles");
 
 
 // Security: The script runs from the cli SAPI only.
 if (php_sapi_name () != "cli") {
-  $database_logs->log ("exports: Fatal: This only runs through the cli Server API", true);
+  $database_logs->log ("exports: Fatal: This only runs through the cli Server API");
   die;
 }
 
@@ -47,9 +47,6 @@ $exportedBibles = $database_config_general->getExportedBibles ();
 $stylesheet = $database_config_general->getExportStylesheet ();
 
 
-unset ($database_config_general);
-
-
 // Where to store the exported Bibles.
 include ("paths/paths.php");
 $exportsDirectory = "$localStatePath/$location/exports";
@@ -67,9 +64,20 @@ foreach ($bibles as $bible) {
   if (!in_array ($bible, $exportedBibles)) continue;
   // The user can access the files through the browser at the directory.
   mkdir ($bibleDirectory);
-  // Folder where the USFM files go.
+  // Folders where the USFM files go.
   $usfmDirectory = $bibleDirectory . "/usfm";
   mkdir ($usfmDirectory);
+  $usfmDirectoryFull = $usfmDirectory . "/full";
+  mkdir ($usfmDirectoryFull);
+  $usfmDirectoryBasic = $usfmDirectory . "/basic";
+  mkdir ($usfmDirectoryBasic);
+  // Copy info for USFM.
+  copy ("usfm.html", "$usfmDirectory/readme.html");
+  // Folder for temporal USFM files for conversion to other formats.
+  $usfmTemporalFolderBasic = uniqid (sys_get_temp_dir() . "/") . "basic";
+  mkdir ($usfmTemporalFolderBasic);
+  $usfmTemporalFolderFull = uniqid (sys_get_temp_dir() . "/") . "full";
+  mkdir ($usfmTemporalFolderFull);
   // Folder for the OpenDocument files.
   $odtDirectory = $bibleDirectory . "/opendocument";
   mkdir ($odtDirectory);
@@ -91,7 +99,40 @@ foreach ($bibles as $bible) {
   // Folder for the information files.
   $infoDirectory = $bibleDirectory . "/info";
   mkdir ($infoDirectory);
+  // Folders for the OSIS files.
+  $osisDirectory = $bibleDirectory . "/osis";
+  mkdir ($osisDirectory);
+  $osisDirectoryBasicPython = $osisDirectory . "/basic-1";
+  mkdir ($osisDirectoryBasicPython);
+  $osisDirectoryFullPython = $osisDirectory . "/full-1";
+  mkdir ($osisDirectoryFullPython);
+  $osisDirectoryBasicPerl = $osisDirectory . "/basic-2";
+  mkdir ($osisDirectoryBasicPerl);
+  $osisDirectoryFullPerl = $osisDirectory . "/full-2";
+  mkdir ($osisDirectoryFullPerl);
+  // Copy info for OSIS.
+  copy ("../osis/osis.html", "$osisDirectory/readme.html");
 
+  // Folders for the Sword files.
+  $swordDirectory = $bibleDirectory . "/sword";
+  mkdir ($swordDirectory);
+  $swordDirectoryBasicPython = $swordDirectory . "/basic-1";
+  mkdir ($swordDirectoryBasicPython);
+  $swordDirectoryFullPython = $swordDirectory . "/full-1";
+  mkdir ($swordDirectoryFullPython);
+  $swordDirectoryBasicPerl = $swordDirectory . "/basic-2";
+  mkdir ($swordDirectoryBasicPerl);
+  $swordDirectoryFullPerl = $swordDirectory . "/full-2";
+  mkdir ($swordDirectoryFullPerl);
+  // Copy info for Sword.
+  $contents = file_get_contents ("../sword/sword.html");
+  $host = $database_config_general->getSiteURL ();
+  $host = parse_url ($host, PHP_URL_HOST);
+  $contents = str_replace ("_host_", "$host", $contents);
+  $contents = str_replace ("_bible_", $bible, $contents);
+  file_put_contents ("$swordDirectory/readme.html", $contents);
+  unset ($contents);
+  unset ($host);
 
   // Back link path.
   $backLinkPath = "../downloads/exports/$bible/web/";
@@ -107,6 +148,8 @@ foreach ($bibles as $bible) {
   $html_text_rich_bible_index->newParagraph ("navigationbar");
   $html_text_rich_bible_index->addText (" |");
 
+  // The filename for the entire Bible in basic USFM.
+  $basicUsfmBibleFilename = $usfmDirectoryBasic . "/00_Bible.usfm";
 
   // Go through the Bible books.
   $books = $database_bibles->getBooks ($bible);
@@ -115,7 +158,7 @@ foreach ($bibles as $bible) {
     // E.g.: Ndebele Genesis
     $bibleBookText = $bible . " " . $database_books->getEnglishFromId ($book);
     
-    $database_logs->log ("exports: " . $bibleBookText, true);
+    $database_logs->log ("exports: " . $bibleBookText);
 
     // Rich web index file per book. 
     $html_text_rich_book_index = new Html_Text ($bibleBookText);
@@ -136,14 +179,27 @@ foreach ($bibles as $bible) {
     $filter_text_book->odf_text_text_only = new Odf_Text;
     $filter_text_book->odf_text_text_and_note_citations = new Odf_Text;
     $filter_text_book->odf_text_notes = new Odf_Text;
+    
+    // Basic USFM.
+    $basicUsfm = "\\id " . $database_books->getUsfmFromId ($book) . "\n";
+    file_put_contents ($basicUsfmBibleFilename, $basicUsfm, FILE_APPEND);
+    $basicUsfmBookFilename = sprintf ("%0" . 2 . "d", $book) . "_" . $database_books->getEnglishFromId ($book) . ".usfm";
+    file_put_contents ("$usfmDirectoryBasic/$basicUsfmBookFilename", $basicUsfm, FILE_APPEND);
+    file_put_contents ("$usfmTemporalFolderBasic/$basicUsfmBookFilename", $basicUsfm, FILE_APPEND);
+    unset ($basicUsfm);
 
     // Go through the chapters in this book.
     $chapters = $database_bibles->getChapters ($bible, $book);
     foreach ($chapters as $chapter) {
-      
-      // Interlinked web data for one chapter.
+
+      // The text filter for this chapter.      
       $filter_text_chapter = new Filter_Text ($bible);
+
+      // Interlinked web data for one chapter.
       $filter_text_chapter->html_text_linked = new Html_Text (gettext ("Bible"));
+      
+      // Basic USFM for this chapter.
+      $filter_text_chapter->initializeHeadingsAndTextPerVerse ();
 
       // Get the USFM code for the current chapter.
       $chapter_data = $database_bibles->getChapter ($bible, $book, $chapter);
@@ -172,12 +228,28 @@ foreach ($bibles as $bible) {
       
       $html_text_rich_book_index->addLink ($html_text_rich_book_index->currentPDomElement, Filter_Paths::htmlFileNameBible ("", $book, $chapter), "", $chapter, "", " " . $chapter . " ");
       $html_text_rich_book_index->addText ("|");
+      
+      // Deal with basic USFM.
+      if ($chapter > 0) {
+        $verses_text = $filter_text_chapter->getVersesText ();
+        $basicUsfm = "\\c $chapter\n";
+        $basicUsfm .= "\\p\n";
+        foreach ($verses_text as $verse => $text) {
+          $basicUsfm .= "\\v $verse $text\n";
+        }
+        file_put_contents ("$usfmDirectoryBasic/$basicUsfmBookFilename", $basicUsfm, FILE_APPEND);
+        file_put_contents ("$usfmTemporalFolderBasic/$basicUsfmBookFilename", $basicUsfm, FILE_APPEND);
+        unset ($verse);
+        unset ($text);
+        unset ($basicUsfm);
+      }
 
     }
 
-    // Save the USFM code of the book to disk.
+    // Save the USFM code of the book the output folder and to the temporal folder.
     $baseBookFileName = sprintf("%0" . 2 . "d", $book) . "_" . $database_books->getEnglishFromId ($book);
-    file_put_contents ("$usfmDirectory/$baseBookFileName.usfm", $bookUsfmData);
+    file_put_contents ("$usfmDirectoryFull/$baseBookFileName.usfm", $bookUsfmData);
+    file_put_contents ("$usfmTemporalFolderFull/$baseBookFileName.usfm", $bookUsfmData);
 
     // Create OpenDocument and Web files for the Bible book.
     $filter_text_book->run ($stylesheet);
@@ -218,7 +290,7 @@ foreach ($bibles as $bible) {
 
 
   // Save index file for the interlinked web export.
-  $database_logs->log ("exports: Create index file for interlinked Web", true);
+  $database_logs->log ("exports: Create index file for interlinked Web");
   $html_text_rich_bible_index->save ("$richWebDirectory/index.html");
   $html_text_rich_bible_index->save ("$richWebDirectory/00_index.html");
   unset ($html_text_rich_bible_index);
@@ -232,7 +304,7 @@ foreach ($bibles as $bible) {
   // Go through the Bible books and chapters.
   // Add the chapter's USFM code to the exporter filter for the whole Bible.
   // Use small chunks of USFM at a time for much better performance.
-  $database_logs->log ("exports: Save entire Bible to USFM", true);
+  $database_logs->log ("exports: Save entire Bible to USFM");
   $bibleUsfmData = "";
   $books = $database_bibles->getBooks ($bible);
   foreach ($books as $book) {
@@ -244,12 +316,12 @@ foreach ($bibles as $bible) {
       $bibleUsfmData .= "\n";
     }
   }
-  file_put_contents ("$usfmDirectory/00_Bible.usfm", $bibleUsfmData);
+  file_put_contents ("$usfmDirectoryFull/00_Bible.usfm", $bibleUsfmData);
   unset ($bibleUsfmData);
 
 
   // Save Bible to the plain Web format.
-  $database_logs->log ("exports: Save entire Bible to plain Web", true);
+  $database_logs->log ("exports: Save entire Bible to plain Web");
   $filter_text_bible = new Filter_Text ($bible);
   $filter_text_bible->html_text_standard = new Html_Text (gettext ("Bible"));
   // Use small chunks of USFM at a time for much better performance.
@@ -269,7 +341,7 @@ foreach ($bibles as $bible) {
 
 
   // Save to Online Bible format.
-  $database_logs->log ("exports: Save entire Bible to Online Bible", true);
+  $database_logs->log ("exports: Save entire Bible to Online Bible");
   $filter_text_bible = new Filter_Text ($bible);
   $filter_text_bible->onlinebible_text = new Onlinebible_Text ();
   $books = $database_bibles->getBooks ($bible);
@@ -288,7 +360,7 @@ foreach ($bibles as $bible) {
 
 
   // Save to eSword module.
-  $database_logs->log ("exports: Save entire Bible to eSword", true);
+  $database_logs->log ("exports: Save entire Bible to eSword");
   $filter_text_bible = new Filter_Text ($bible);
   $filter_text_bible->esword_text = new Esword_Text ($bible);
   $books = $database_bibles->getBooks ($bible);
@@ -308,7 +380,7 @@ foreach ($bibles as $bible) {
 
 
   // Export to OpenDocument in standard Bible format: Text plus footnotes.
-  $database_logs->log ("exports: Save entire Bible to OpenDocument: Text plus footnotes", true);
+  $database_logs->log ("exports: Save entire Bible to OpenDocument: Text plus footnotes");
   $filter_text_bible = new Filter_Text ($bible);
   $filter_text_bible->odf_text_standard = new Odf_Text;
   $books = $database_bibles->getBooks ($bible);
@@ -335,7 +407,7 @@ foreach ($bibles as $bible) {
 
 
   // Export to OpenDocument in text-only format.
-  $database_logs->log ("exports: Save entire Bible to OpenDocument: Text only", true);
+  $database_logs->log ("exports: Save entire Bible to OpenDocument: Text only");
   $filter_text_bible = new Filter_Text ($bible);
   $filter_text_bible->odf_text_text_only = new Odf_Text;
   $books = $database_bibles->getBooks ($bible);
@@ -354,7 +426,7 @@ foreach ($bibles as $bible) {
 
 
   // Export to OpenDocument in text plus note citations format.
-  $database_logs->log ("exports: Save entire Bible to OpenDocument: Text plus note citations", true);
+  $database_logs->log ("exports: Save entire Bible to OpenDocument: Text plus note citations");
   $filter_text_bible = new Filter_Text ($bible);
   $filter_text_bible->odf_text_text_and_note_citations = new Odf_Text;
   $books = $database_bibles->getBooks ($bible);
@@ -373,7 +445,7 @@ foreach ($bibles as $bible) {
 
 
   // Export to OpenDocument in notes-only format.
-  $database_logs->log ("exports: Save entire Bible to OpenDocument: Notes only", true);
+  $database_logs->log ("exports: Save entire Bible to OpenDocument: Notes only");
   $filter_text_bible = new Filter_Text ($bible);
   $filter_text_bible->odf_text_notes = new Odf_Text;
   $books = $database_bibles->getBooks ($bible);
@@ -393,10 +465,43 @@ foreach ($bibles as $bible) {
   // Lens image supporting search.
   copy ("../webbible/lens.png", "$richWebDirectory/lens.png");
 
+  // Export to OSIS format.
+  $database_logs->log ("exports: Convert Bible from full USFM to OSIS through Python");
+  $osis_text = new Osis_Text ($usfmTemporalFolderFull, $osisDirectoryFullPython, $bible);
+  $osis_text->run ('py');
+  $database_logs->log ("exports: Convert Bible from basic USFM to OSIS through Python");
+  $osis_text = new Osis_Text ($usfmTemporalFolderBasic, $osisDirectoryBasicPython, $bible);
+  $osis_text->run ('py');
+  $database_logs->log ("exports: Convert Bible from full USFM to OSIS through Perl");
+  $osis_text = new Osis_Text ($usfmTemporalFolderFull, $osisDirectoryFullPerl, $bible);
+  $osis_text->run ('pl');
+  $database_logs->log ("exports: Convert Bible from basic USFM to OSIS through Perl");
+  $osis_text = new Osis_Text ($usfmTemporalFolderBasic, $osisDirectoryBasicPerl, $bible);
+  $osis_text->run ('pl');
+  unset ($osis_text);
+
+  // Export to various Sword module.
+  $database_logs->log ("exports: Create various Sword modules");
+  $sword_text = new Sword_Text ($osisDirectoryBasicPython, $swordDirectoryBasicPython, $bible);
+  $sword_text->run ("00_Bible.xml");
+  $sword_text = new Sword_Text ($osisDirectoryFullPython, $swordDirectoryFullPython, $bible);
+  $sword_text->run ("00_Bible.xml");
+  $sword_text = new Sword_Text ($osisDirectoryBasicPerl, $swordDirectoryBasicPerl, $bible);
+  $sword_text->run ("00_Bible.xml");
+  $sword_text = new Sword_Text ($osisDirectoryFullPerl, $swordDirectoryFullPerl, $bible);
+  $sword_text->run ("00_Bible.xml");
+  // Make the Sword folder readable for the FTP server for the module repository.
+  system ("cd ". escapeshellarg ($swordDirectory) . " ; chmod -R +r *");
+  
+  // Remove the temporal folders containing USFM for conversion.
+  Filter_Rmdir::rmdir ($usfmTemporalFolderBasic);
+  Filter_Rmdir::rmdir ($usfmTemporalFolderFull);
+
+
 }
 
 
-$database_logs->log ("exports: Completed", true);
+$database_logs->log ("exports: Completed");
 
 
 ?>
