@@ -41,7 +41,6 @@ posix_setegid ($pwnam['gid']);
 
 ignore_user_abort (true);
 set_time_limit (0);
-register_shutdown_function ('shutdown');
 
 
 $config_general = Database_Config_General::getInstance ();
@@ -60,9 +59,11 @@ $minute = date ('i');
 
 
 // Every minute send out any queued mail.
-$timer_mailer = new Timer_Mailer ();
-$timer_mailer->run ();
-unset ($timer_mailer);
+$workingdirectory = escapeshellarg (dirname (__FILE__));
+$logfilename = $timer_logger->getLogFilename (Timer_Logger::mailer);
+$command = "cd $workingdirectory; php mailer.php > $logfilename 2>&1 & echo $!";
+$pid = shell_exec ($command);
+$timer_logger->registerLogfile ($command, $pid, $logfilename, false);
 
 
 // Every minute deal with any log files that were used for the scripts.
@@ -72,22 +73,25 @@ $timer_logger->handleUsedLogFiles ();
 // Check for new mail every five minutes.
 // Do not check more often with gmail else the account may be shut down.
 if (($minute % 5) == 0) {
-  $timer_receiver = new Timer_Receiver ();
-  $timer_receiver->run ();
-  unset ($timer_receiver);
+  $workingdirectory = escapeshellarg (dirname (__FILE__));
+  $logfilename = $timer_logger->getLogFilename (Timer_Logger::receiver);
+  $command = "cd $workingdirectory; php receiver.php > $logfilename 2>&1 & echo $!";
+  $pid = shell_exec ($command);
+  $timer_logger->registerLogfile ($command, $pid, $logfilename, false);
 }
 
 
-// The running order of the following nightly scripts is important.
-// In general, the order will such that all information is generated as recent as possible,
-// and that the more important tasks are done first, and the less important ones at the end.
-// This means something as displayed in the code of this script.
+// The order for running the following nightly scripts is important.
+// Any of those scripts may influence the subsequent ones.
+// The order is such that all information generated is as recent as possible.
+// More important tasks are done first, and the less important ones at the end.
+// This leads to an order as visible in the code below.
 
 
 // Sending and receiving Bibles to and from the git repository.
 // On a production website running on an inexpensive virtual private server 
 // with 512 Mbyte of memory and a fast network connection, 
-// sending and receiving two Bibles takes less than a minute.
+// sending and receiving two Bibles takes more than 15 minutes when there are many changes.
 if (($current_timestamp >= $config_general->getTimerSendReceive ()) || (($hour == 0) && ($minute == 0))) {
   $config_general->setTimerSendReceive ($current_timestamp + 100000);
   $workingdirectory = escapeshellarg (dirname (__FILE__));
@@ -100,7 +104,7 @@ if (($current_timestamp >= $config_general->getTimerSendReceive ()) || (($hour =
 
 // Sending the daily changes in the Bibles by email.
 // This takes a few minutes on a production machine with two Bibles and changes in several chapters.
-if (($current_timestamp >= $config_general->getTimerDiff ()) || (($hour == 0) && ($minute == 5))) {
+if (($current_timestamp >= $config_general->getTimerDiff ()) || (($hour == 0) && ($minute == 20))) {
   $config_general->setTimerDiff ($current_timestamp + 100000);
   $workingdirectory = escapeshellarg (dirname (__FILE__));
   $logfilename = $timer_logger->getLogFilename (Timer_Logger::changes);
@@ -111,8 +115,8 @@ if (($current_timestamp >= $config_general->getTimerDiff ()) || (($hour == 0) &&
 
 
 // Run the checks on the Bibles.
-// This takes 20 minutes on a production machine with two Bibles.
-if (($current_timestamp >= $config_general->getTimerChecks ()) || (($hour == 0) && ($minute == 10))) {
+// This takes 15 minutes on a production machine with two Bibles.
+if (($current_timestamp >= $config_general->getTimerChecks ()) || (($hour == 0) && ($minute == 25))) {
   $config_general->setTimerChecks ($current_timestamp + 100000);
   $workingdirectory = dirname (__FILE__);
   $logfilename = $timer_logger->getLogFilename (Timer_Logger::checks);
@@ -122,12 +126,12 @@ if (($current_timestamp >= $config_general->getTimerChecks ()) || (($hour == 0)
 }
 
 
-// Trim the tables in the database.
-//  It takes about half an hour on a production machine with many snapshots.
-if (($hour == 0) && ($minute == 35)) {
+// Database maintenance and trimming.
+// It takes a few minutes on a production machine..
+if (($hour == 0) && ($minute == 40)) {
   $workingdirectory = dirname (__FILE__);
-  $logfilename = $timer_logger->getLogFilename (Timer_Logger::trimdatabases);
-  $command = "cd $workingdirectory; php trimdatabases.php > $logfilename 2>&1 & echo $!";
+  $logfilename = $timer_logger->getLogFilename (Timer_Logger::database);
+  $command = "cd $workingdirectory; php database.php > $logfilename 2>&1 & echo $!";
   $pid = shell_exec ($command);
   $timer_logger->registerLogfile ($command, $pid, $logfilename);
 }
@@ -135,7 +139,7 @@ if (($hour == 0) && ($minute == 35)) {
 
 // Create a backup, so that the backup contains the most recent information
 // after the previous tasks have been done.
-if (($current_timestamp >= $config_general->getTimerBackup ()) || (($hour == 1) && ($minute == 5))) {
+if (($current_timestamp >= $config_general->getTimerBackup ()) || (($hour == 0) && ($minute == 45))) {
   $config_general->setTimerBackup ($current_timestamp + 100000);
   $workingdirectory = dirname (__FILE__);
   $logfilename = $timer_logger->getLogFilename (Timer_Logger::backup);
@@ -145,8 +149,19 @@ if (($current_timestamp >= $config_general->getTimerBackup ()) || (($hour == 1)
 }
 
 
+// Email statistics to the users.
+if (($hour == 0) && ($minute == 50)) {
+  $workingdirectory = escapeshellarg (dirname (__FILE__));
+  $logfilename = $timer_logger->getLogFilename (Timer_Logger::statistics);
+  $command = "cd $workingdirectory; php statistics.php > $logfilename 2>&1 & echo $!";
+  $pid = shell_exec ($command);
+  $timer_logger->registerLogfile ($command, $pid, $logfilename);
+}
+
+
 // Export the Bibles to the various output formats.
-if (($current_timestamp >= $config_general->getTimerExports ()) || (($hour == 1) && ($minute == 25))) {
+// This may take an hour on a production machine.
+if (($current_timestamp >= $config_general->getTimerExports ()) || (($hour == 0) && ($minute == 55))) {
   $config_general->setTimerExports ($current_timestamp + 100000);
   $workingdirectory = escapeshellarg (dirname (__FILE__));
   $logfilename = $timer_logger->getLogFilename (Timer_Logger::exports);
@@ -156,9 +171,4 @@ if (($current_timestamp >= $config_general->getTimerExports ()) || (($hour == 1)
 }
 
 
-function shutdown()
-{
-}
-
-
 ?>
