@@ -3,7 +3,8 @@
 
 require_once ("../bootstrap/bootstrap.php");
 page_access_level (MANAGER_LEVEL);
-$smarty = new Smarty_Bibledit (__FILE__);
+Assets_Page::header (gettext ("Versifications"));
+$view = new Assets_View (__FILE__);
 $database_versifications = Database_Versifications::getInstance();
 
 
@@ -32,8 +33,9 @@ if (isset ($_GET['new'])) {
 
 
 $systems = $database_versifications->getSystems();
-$smarty->assign ("systems", $systems);
-$smarty->display ("index.tpl");
+$view->view->systems = $systems;
+$view->render ("index.php");
+Assets_Page::footer ();
 
 
-?>
\ No newline at end of file
+?>
